package agent

import (
	"agent/src/prompt"
	"context"
	"fmt"
	"strings"
	"testing"
)

func TestAgent(t *testing.T) {
	ctx := context.Background()
	a := NewAgent(ctx, "../../docs")
	crt := "../../config"
	a.Start(8080, &crt)
	<-make(chan bool)
}


func Test001(t *testing.T) {
	s := "\u003cthink\u003e\nOkay, so I'm trying to understand this code that someone provided. It's about creating a snake game using Python and Tkinter. The selected portion is the __init__ method of the Food class. Let me break it down step by step.\n\nFirst, I see that the Food class has an __init__ method. That means when a new instance of Food is created, this method runs automatically. Inside this method, there are some variables being set: x and y. They're using random.randint to generate these values. \n\nLooking at how x is calculated: it's random.randint(0, (WIDTH / SPACE_SIZE) - 1) multiplied by SPACE_SIZE. Similarly for y. I think WIDTH and HEIGHT are the dimensions of the game window, and SPACE_SIZE is probably the size of each grid block or the size of the food item. So, dividing WIDTH by SPACE_SIZE gives the number of possible positions along the width. Subtracting 1 ensures that the random number doesn't go out of bounds when multiplied back by SPACE_SIZE.\n\nSo x and y are being set to a position within the game window, in increments of SPACE_SIZE. That makes sense because it keeps the food aligned with the grid where the snake moves.\n\nNext, self.coordinates is assigned as a list [x, y]. This probably holds the current position of the food so that other parts of the code can check if the snake has eaten it.\n\nThen there's a call to canvas.create_oval. The parameters are x, y for the top-left corner and x + SPACE_SIZE, y + SPACE_SIZE for the bottom-right corner. The fill color is FOOD, which I assume is defined earlier as a constant. The tag \"food\" might be used later to identify this object on the canvas.\n\nPutting it all together, when a Food object is created, it randomly places an oval-shaped food item somewhere on the game canvas. This position is stored so that the snake can check for collisions or eating events in subsequent turns.\n\nI'm a bit confused about why they use create_oval instead of another shape, but I guess it's just a design choice. Also, I wonder how the food respawns when eaten. Maybe there's another part of the code that deletes the old food and creates a new instance of Food, which would call this __init__ method again.\n\nAnother thing to note is that the coordinates are stored as [x, y], which will be used in collision detection with the snake's head. If the snake's head position matches the food's coordinates, then the snake grows, and the score increases.\n\nI think I've got a good grasp of what this code does now. It initializes the food at a random valid position on the canvas and sets up its visual representation.\n\u003c/think\u003e\n\nThe selected code is from the `__init__` method of the `Food` class in a Python-based snake game. Here's an explanation of its logic:\n\n1. **Random Position Calculation**:\n   - The `x` and `y` coordinates for the food are determined using `random.randint()`.\n   - `(WIDTH / SPACE_SIZE) - 1` calculates the maximum index along the width, ensuring the food stays within bounds.\n   - Multiplying by `SPACE_SIZE` converts this index to pixel coordinates.\n\n2. **Storing Coordinates**:\n   - The food's position is stored in `self.coordinates` as `[x, y]`, allowing other parts of the code to check for collisions with the snake.\n\n3. **Visual Representation**:\n   - An oval is drawn on the canvas using `create_oval()`, positioned at `(x, y)` with dimensions based on `SPACE_SIZE`.\n   - The color is set to `FOOD` (defined earlier), and tagged as \"food\" for easy reference.\n\nThis method initializes the food's position and appearance each time a new `Food` object is created."
	fmt.Println(prompt.RemoveThinkPart(s))
}

func Test002(t *testing.T) {
	prompt_docstring := strings.Replace(
	`a
	file: {%s}
	"""
	{%s}
	"""
	`,
	"\"\"\"", "```", 2)
	fmt.Println(prompt_docstring)
	// fmt.Println(fmt.Sprintf(prompt_docstring, "a", "b"))
}