package llm

import (
	"agent/src/utils"
	"context"

	"github.com/tmc/langchaingo/llms"
	"github.com/tmc/langchaingo/llms/ollama"
)

var LLMGroups map[string]*LLMGroup
var LLMNames []string

func init() {
	LLMGroups = make(map[string]*LLMGroup)
	llm, err := ollama.New(ollama.WithServerURL("http://192.168.1.5:11434"), ollama.WithModel("deepseek-r1:32b"))
	if err != nil {
		panic(err)
	}
	g := &LLMGroup{
		name: "local deepseek-r1:32b",
		llm: make(chan llms.Model, 1),
		local: true,
	}
	g.llm <- llm
	LLMGroups["local deepseek-r1:32b"] = g

	llm, err = ollama.New(ollama.WithServerURL("http://192.168.1.5:11434"), ollama.WithModel("deepseek-coder-v2:16b"))
	if err != nil {
		panic(err)
	}
	g = &LLMGroup{
		name: "local deepseek-coder-v2:16b",
		llm: make(chan llms.Model, 1),
		local: true,
	}
	g.llm <- llm
	LLMGroups["local deepseek-coder-v2:16b"] = g

	LLMNames = utils.MapKeys(LLMGroups)
}



type LLMGroup struct {
	name  string
	llm   chan llms.Model
	local bool
}

func (g *LLMGroup) Name() string { return g.name }
func (g *LLMGroup) IsLocal() bool { return g.local }
func (g *LLMGroup) Cap() int { return cap(g.llm) }

func (g *LLMGroup) GenerateContent(ctx context.Context, messages []llms.MessageContent, options ...llms.CallOption) (*llms.ContentResponse, error) {
	m := <-g.llm
	defer func(){
		g.llm <- m
	}()
	return m.GenerateContent(ctx, messages, options...)
}

// use streaming if stream is not nil
func (g *LLMGroup) Chat(ctx context.Context, msg string, options ...llms.CallOption) (string, error) {
	contents := []llms.MessageContent{llms.TextParts(llms.ChatMessageTypeHuman, msg)}
	return g.ChatContents(ctx, contents, options...)
}

// use streaming if stream is not nil
func (g *LLMGroup) ChatContents(ctx context.Context, contents []llms.MessageContent, options ...llms.CallOption) (string, error) {
	m := <-g.llm
	defer func(){
		g.llm <- m
	}()

	options = append(options, llms.WithN(1))
	res, err := m.GenerateContent(ctx, contents, options...)
	if err != nil {
		return "", err
	}
	if len(res.Choices) == 0 {
		return "", nil
	}
	return res.Choices[0].Content, nil
}

// block util available
func (g LLMGroup) Get() llms.Model {
	return <-g.llm
}

func ContainLLM(name string) bool {
	_, ok := LLMGroups[name]
	return ok
}
